Module: Google::Cloud::Bigquery::Reservation
- Defined in:
- lib/google/cloud/bigquery/reservation.rb,
lib/google/cloud/bigquery/reservation/version.rb
Constant Summary collapse
- VERSION =
"1.6.2"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.bigquery_reservation| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-bigquery-reservation library.
-
.reservation_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ReservationService.
-
.reservation_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ReservationService service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.bigquery_reservation| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-bigquery-reservation library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
161 162 163 164 165 |
# File 'lib/google/cloud/bigquery/reservation.rb', line 161 def self.configure yield ::Google::Cloud.configure.bigquery_reservation if block_given? ::Google::Cloud.configure.bigquery_reservation end |
.reservation_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ReservationService.
By default, this returns an instance of
Google::Cloud::Bigquery::Reservation::V1::ReservationService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ReservationService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ReservationService service. You can determine whether the method will succeed by calling reservation_service_available?.
About ReservationService
This API allows users to manage their BigQuery reservations.
A reservation provides computational resource guarantees, in the form of
slots, to users. A slot is a
unit of computational power in BigQuery, and serves as the basic unit of
parallelism. In a scan of a multi-partitioned table, a single slot operates
on a single partition of the table. A reservation resource exists as a child
resource of the admin project and location, e.g.:
projects/myproject/locations/US/reservations/reservationName.
A capacity commitment is a way to purchase compute capacity for BigQuery jobs
(in the form of slots) with some committed period of usage. A capacity
commitment resource exists as a child resource of the admin project and
location, e.g.:
projects/myproject/locations/US/capacityCommitments/id.
90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/google/cloud/bigquery/reservation.rb', line 90 def self.reservation_service version: :v1, transport: :grpc, &block require "google/cloud/bigquery/reservation/#{version.to_s.downcase}" package_name = Google::Cloud::Bigquery::Reservation .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Bigquery::Reservation.const_get(package_name).const_get(:ReservationService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.reservation_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ReservationService service is supported by the current client. If true, you can retrieve a client object by calling reservation_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ReservationService service, or if the versioned client gem needs an update to support the ReservationService service.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/google/cloud/bigquery/reservation.rb', line 114 def self.reservation_service_available? version: :v1, transport: :grpc require "google/cloud/bigquery/reservation/#{version.to_s.downcase}" package_name = Google::Cloud::Bigquery::Reservation .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Bigquery::Reservation.const_get package_name return false unless service_module.const_defined? :ReservationService service_module = service_module.const_get :ReservationService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |